@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -38,6 +38,7 @@ from typing import (
 )
 
 # Bokeh imports
+from ...util.dependencies import uses_pandas
 from ...util.strings import nice_join
 from ..has_props import HasProps
 from ._sphinx import property_link, register_type_link, type_link
@@ -59,10 +60,6 @@ if TYPE_CHECKING:
 # Globals and constants
 #-----------------------------------------------------------------------------
 
-#-----------------------------------------------------------------------------
-# General API
-#-----------------------------------------------------------------------------
-
 __all__ = (
     'ContainerProperty',
     'PrimitiveProperty',
@@ -70,6 +67,10 @@ __all__ = (
     'validation_on',
 )
 
+#-----------------------------------------------------------------------------
+# General API
+#-----------------------------------------------------------------------------
+
 #-----------------------------------------------------------------------------
 # Dev API
 #-----------------------------------------------------------------------------
@@ -247,19 +248,19 @@ class Property(PropertyDescriptorFactory[T]):
 
         """
         import numpy as np
-        import pandas as pd
 
         if isinstance(new, np.ndarray) or isinstance(old, np.ndarray):
             return np.array_equal(new, old)
 
-        if isinstance(new, pd.Series) or isinstance(old, pd.Series):
-            return np.array_equal(new, old)
+        if uses_pandas(new) or uses_pandas(old):
+            import pandas as pd
 
-        if isinstance(new, pd.Index) or isinstance(old, pd.Index):
-            return np.array_equal(new, old)
+            if isinstance(new, pd.Series) or isinstance(old, pd.Series):
+                return np.array_equal(new, old)
+            if isinstance(new, pd.Index) or isinstance(old, pd.Index):
+                return np.array_equal(new, old)
 
         try:
-
             # this handles the special but common case where there is a dict with array
             # or series as values (e.g. the .data property of a ColumnDataSource)
             if isinstance(new, dict) and isinstance(old, dict):
