@@ -1,10 +1,10 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
 #-----------------------------------------------------------------------------
-""" Provide properties for various visual attrributes.
+""" Provide properties for various visual attributes.
 
 """
 
@@ -24,15 +24,12 @@ log = logging.getLogger(__name__)
 import base64
 import datetime  # lgtm [py/import-and-import-from]
 import re
+import tempfile
 from io import BytesIO
 from pathlib import Path
-from typing import Any
-
-# External imports
-import PIL.Image
+from typing import Any, BinaryIO
 
 # Bokeh imports
-from ...util.deprecation import deprecated
 from ...util.serialization import convert_datetime_type
 from .. import enums
 from .auto import Auto
@@ -154,6 +151,7 @@ class Image(Property):
 
     def validate(self, value: Any, detail: bool = True) -> None:
         import numpy as np
+        import PIL.Image
 
         if isinstance(value, (str, Path, PIL.Image.Image)):
             return
@@ -167,17 +165,16 @@ class Image(Property):
 
     def transform(self, value):
         import numpy as np
+        import PIL.Image
+
         if isinstance(value, np.ndarray):
             value = PIL.Image.fromarray(value)
 
-        if isinstance(value, str) and value.startswith("data:image/"):
+        if isinstance(value, str):
             return value
 
-        if isinstance(value, str):
-            deprecated((2, 4, 0), "raw string path", "pathlib.Path")
-            value = Path(value)
-
-        if isinstance(value, Path):
+        # tempfile doesn't implement IO interface (https://bugs.python.org/issue33762)
+        if isinstance(value, (Path, BinaryIO, tempfile._TemporaryFileWrapper)):
             value = PIL.Image.open(value)
 
         if isinstance(value, PIL.Image.Image):
