@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -122,7 +122,7 @@ def autoload_static(model: Model | Document, resources: Resources, script_path:
     bundle = bundle_for_objs_and_resources(None, resources)
     bundle.add(Script(script_for_render_items(docs_json, [render_item])))
 
-    (_, elementid) = list(render_item.roots.to_json().items())[0]
+    (_, elementid) = next(iter(render_item.roots.to_json().items()))
 
     js = wrap_in_onload(AUTOLOAD_JS.render(bundle=bundle, elementid=elementid))
 
@@ -134,21 +134,21 @@ def autoload_static(model: Model | Document, resources: Resources, script_path:
     return js, tag
 
 @overload
-def components(models: Model, wrap_script: bool = ..., # type: ignore[misc] # XXX: mypy bug
+def components(models: Model, wrap_script: bool = ..., # type: ignore[overload-overlap] # XXX: mypy bug
     wrap_plot_info: Literal[True] = ..., theme: ThemeLike = ...) -> tuple[str, str]: ...
 @overload
 def components(models: Model, wrap_script: bool = ..., wrap_plot_info: Literal[False] = ...,
     theme: ThemeLike = ...) -> tuple[str, RenderRoot]: ...
 
 @overload
-def components(models: Sequence[Model], wrap_script: bool = ..., # type: ignore[misc] # XXX: mypy bug
+def components(models: Sequence[Model], wrap_script: bool = ..., # type: ignore[overload-overlap] # XXX: mypy bug
     wrap_plot_info: Literal[True] = ..., theme: ThemeLike = ...) -> tuple[str, Sequence[str]]: ...
 @overload
 def components(models: Sequence[Model], wrap_script: bool = ..., wrap_plot_info: Literal[False] = ...,
     theme: ThemeLike = ...) -> tuple[str, Sequence[RenderRoot]]: ...
 
 @overload
-def components(models: dict[str, Model], wrap_script: bool = ..., # type: ignore[misc] # XXX: mypy bug
+def components(models: dict[str, Model], wrap_script: bool = ..., # type: ignore[overload-overlap] # XXX: mypy bug
     wrap_plot_info: Literal[True] = ..., theme: ThemeLike = ...) -> tuple[str, dict[str, str]]: ...
 @overload
 def components(models: dict[str, Model], wrap_script: bool = ..., wrap_plot_info: Literal[False] = ...,
