@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -26,12 +26,8 @@ from contextlib import contextmanager
 from typing import (
     TYPE_CHECKING,
     Any,
-    Dict,
     Iterator,
-    List,
     Sequence,
-    Tuple,
-    Type,
 )
 from weakref import WeakKeyDictionary
 
@@ -41,7 +37,8 @@ from ..document.document import Document
 from ..model import Model, collect_models
 from ..settings import settings
 from ..themes.theme import Theme
-from ..util.serialization import make_globally_unique_id
+from ..util.dataclasses import dataclass, field
+from ..util.serialization import make_globally_unique_css_safe_id, make_globally_unique_id
 
 if TYPE_CHECKING:
     from ..document.document import DocJson
@@ -79,7 +76,7 @@ class FromCurdoc:
     pass
 
 @contextmanager
-def OutputDocumentFor(objs: Sequence[Model], apply_theme: Theme | Type[FromCurdoc] | None = None,
+def OutputDocumentFor(objs: Sequence[Model], apply_theme: Theme | type[FromCurdoc] | None = None,
         always_new: bool = False) -> Iterator[Document]:
     ''' Find or create a (possibly temporary) Document to use for serializing
     Bokeh content.
@@ -135,7 +132,7 @@ def OutputDocumentFor(objs: Sequence[Model], apply_theme: Theme | Type[FromCurdo
     # has models with the same IDs as they were started with
 
     if not isinstance(objs, Sequence) or len(objs) == 0 or not all(isinstance(x, Model) for x in objs):
-        raise ValueError("OutputDocumentFor expects a sequence of Models")
+        raise ValueError("OutputDocumentFor expects a non-empty sequence of Models")
 
     def finish() -> None:
         pass
@@ -143,12 +140,12 @@ def OutputDocumentFor(objs: Sequence[Model], apply_theme: Theme | Type[FromCurdo
     docs = {obj.document for obj in objs if obj.document is not None}
 
     if always_new:
-        def finish() -> None: # NOQA
+        def finish() -> None:  # noqa
             _dispose_temp_doc(objs)
         doc = _create_temp_doc(objs)
     else:
         if len(docs) == 0:
-            doc = Document()
+            doc = _new_doc()
             for model in objs:
                 doc.add_root(model)
 
@@ -158,7 +155,7 @@ def OutputDocumentFor(objs: Sequence[Model], apply_theme: Theme | Type[FromCurdo
 
             # we are not using all the roots, make a quick clone for outputting purposes
             if set(objs) != set(doc.roots):
-                def finish() -> None: # NOQA
+                def finish() -> None:
                     _dispose_temp_doc(objs)
                 doc = _create_temp_doc(objs)
 
@@ -167,7 +164,7 @@ def OutputDocumentFor(objs: Sequence[Model], apply_theme: Theme | Type[FromCurdo
 
         # models have mixed docs, just make a quick clone
         else:
-            def finish(): # NOQA
+            def finish():
                 _dispose_temp_doc(objs)
             doc = _create_temp_doc(objs)
 
@@ -183,7 +180,7 @@ def OutputDocumentFor(objs: Sequence[Model], apply_theme: Theme | Type[FromCurdo
 
 class RenderItem:
     def __init__(self, docid: ID | None = None, token: str | None = None, elementid: ID | None = None,
-            roots: List[Model] | Dict[Model, ID] | None = None, use_for_title: bool | None = None):
+            roots: list[Model] | dict[Model, ID] | None = None, use_for_title: bool | None = None):
 
         if (docid is None and token is None) or (docid is not None and token is not None):
             raise ValueError("either docid or sessionid must be provided")
@@ -199,8 +196,8 @@ class RenderItem:
         self.roots = RenderRoots(roots)
         self.use_for_title = use_for_title
 
-    def to_json(self) -> Dict[str, Any]:
-        json: Dict[str, Any] = {}
+    def to_json(self) -> dict[str, Any]:
+        json: dict[str, Any] = {}
 
         if self.docid is not None:
             json["docid"] = self.docid
@@ -226,22 +223,34 @@ class RenderItem:
             return self.to_json() == other.to_json()
 
 
+@dataclass
 class RenderRoot:
-    def __init__(self, elementid: ID, id: ID, name: str | None = None, tags: List[Any] | None = None) -> None:
-        self.elementid = elementid
-        self.id = id
-        self.name = name or ""
-        self.tags = tags or []
+    """ Encapsulate data needed for embedding a Bokeh document root.
 
-    def __eq__(self, other: Any) -> bool:
-        if not isinstance(other, self.__class__):
-            return False
-        else:
-            return self.elementid == other.elementid
+    Values for ``name`` or ``tags`` are optional. They may be useful for
+    querying a collection of roots to find a specific one to embed.
+
+    """
+
+    #: A unique ID to use for the DOM element
+    elementid: ID
+
+    #: The Bokeh model ID for this root
+    id: ID = field(compare=False)
+
+    #: An optional user-supplied name for this root
+    name: str | None = field(default="", compare=False)
+
+    #: A list of any user-supplied tag values for this root
+    tags: list[Any] = field(default_factory=list, compare=False)
+
+    def __post_init__(self):
+        # Model.name is nullable, and field() won't enforce the default when name=None
+        self.name = self.name or ""
 
 
 class RenderRoots:
-    def __init__(self, roots: Dict[Model, ID]) -> None:
+    def __init__(self, roots: dict[Model, ID]) -> None:
         self._roots = roots
 
     def __iter__(self) -> Iterator[RenderRoot]:
@@ -259,25 +268,28 @@ class RenderRoots:
                 if root.name == key:
                     break
             else:
-                raise ValueError("root with '%s' name not found" % key)
+                raise ValueError(f"root with {key!r} name not found")
 
         return RenderRoot(elementid, root.id, root.name, root.tags)
 
     def __getattr__(self, key: str) -> RenderRoot:
         return self.__getitem__(key)
 
-    def to_json(self) -> Dict[ID, ID]:
+    def to_json(self) -> dict[ID, ID]:
         return {root.id: elementid for root, elementid in self._roots.items()}
 
-def standalone_docs_json(models: Sequence[Model | Document]) -> Dict[ID, DocJson]:
+    def __repr__(self) -> str:
+        return repr(self._roots)
+
+def standalone_docs_json(models: Sequence[Model | Document]) -> dict[ID, DocJson]:
     '''
 
     '''
     docs_json, _ = standalone_docs_json_and_render_items(models)
     return docs_json
 
-def standalone_docs_json_and_render_items(models: Model | Document | Sequence[Model | Document],
-        suppress_callback_warning: bool = False) -> Tuple[Dict[ID, DocJson], List[RenderItem]]:
+def standalone_docs_json_and_render_items(models: Model | Document | Sequence[Model | Document], *,
+        suppress_callback_warning: bool = False) -> tuple[dict[ID, DocJson], list[RenderItem]]:
     '''
 
     '''
@@ -290,7 +302,7 @@ def standalone_docs_json_and_render_items(models: Model | Document | Sequence[Mo
     if submodel_has_python_callbacks(models) and not suppress_callback_warning:
         log.warning(_CALLBACKS_WARNING)
 
-    docs: Dict[Document, Tuple[ID, Dict[Model, ID]]] = {}
+    docs: dict[Document, tuple[ID, dict[Model, ID]]] = {}
     for model_or_doc in models:
         if isinstance(model_or_doc, Document):
             model = None
@@ -308,16 +320,16 @@ def standalone_docs_json_and_render_items(models: Model | Document | Sequence[Mo
         (docid, roots) = docs[doc]
 
         if model is not None:
-            roots[model] = make_globally_unique_id()
+            roots[model] = make_globally_unique_css_safe_id()
         else:
             for model in doc.roots:
-                roots[model] = make_globally_unique_id()
+                roots[model] = make_globally_unique_css_safe_id()
 
-    docs_json: Dict[ID, DocJson] = {}
+    docs_json: dict[ID, DocJson] = {}
     for doc, (docid, _) in docs.items():
-        docs_json[docid] = doc.to_json()
+        docs_json[docid] = doc.to_json(deferred=False)
 
-    render_items: List[RenderItem] = []
+    render_items: list[RenderItem] = []
     for _, (docid, roots) in docs.items():
         render_items.append(RenderItem(docid, roots=roots))
 
@@ -385,8 +397,17 @@ be used. For more information on building and running Bokeh applications, see:
     https://docs.bokeh.org/en/latest/docs/user_guide/server.html
 """
 
-def _create_temp_doc(models: Sequence[Model]) -> Document:
+def _new_doc() -> Document:
+    # TODO: embed APIs need to actually respect the existing document's
+    # configuration, but for now this is better than nothing.
+    from ..io import curdoc
     doc = Document()
+    callbacks = curdoc().callbacks._js_event_callbacks
+    doc.callbacks._js_event_callbacks.update(callbacks)
+    return doc
+
+def _create_temp_doc(models: Sequence[Model]) -> Document:
+    doc = _new_doc()
     for m in models:
         doc.models[m.id] = m
         m._temp_document = doc
@@ -404,10 +425,10 @@ def _dispose_temp_doc(models: Sequence[Model]) -> None:
 
 _themes: WeakKeyDictionary[Document, Theme] = WeakKeyDictionary()
 
-def _set_temp_theme(doc: Document, apply_theme: Theme | Type[FromCurdoc] | None) -> None:
+def _set_temp_theme(doc: Document, apply_theme: Theme | type[FromCurdoc] | None) -> None:
     _themes[doc] = doc.theme
     if apply_theme is FromCurdoc:
-        from ..io import curdoc; curdoc
+        from ..io import curdoc
         doc.theme = curdoc().theme
     elif isinstance(apply_theme, Theme):
         doc.theme = apply_theme
