@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -22,6 +22,8 @@ log = logging.getLogger(__name__)
 
 # Standard library imports
 import json
+import os
+import urllib
 from typing import (
     TYPE_CHECKING,
     Any,
@@ -29,6 +31,7 @@ from typing import (
     Literal,
     Protocol,
     TypedDict,
+    Union,
     cast,
     overload,
 )
@@ -37,6 +40,7 @@ from uuid import uuid4
 ## External imports
 if TYPE_CHECKING:
     from ipykernel.comm import Comm
+    from typing_extensions import TypeAlias
 
 # Bokeh imports
 from ..core.types import ID
@@ -71,6 +75,8 @@ LOAD_MIME_TYPE = 'application/vnd.bokehjs_load.v0+json'
 
 EXEC_MIME_TYPE = 'application/vnd.bokehjs_exec.v0+json'
 
+DEFAULT_JUPYTER_URL = "localhost:8888"
+
 __all__ = (
     'CommsHandle',
     'destroy_server',
@@ -107,7 +113,7 @@ class CommsHandle:
             assert ip is not None
             hm = ip.history_manager
             assert hm is not None
-            p_prompt = list(hm.get_tail(1, include_latest=True))[0][1]
+            p_prompt = next(iter(hm.get_tail(1, include_latest=True)))[1]
             self._cellno = p_prompt
         except Exception as e:
             log.debug("Could not get Notebook cell number, reason: %s", e)
@@ -162,7 +168,7 @@ class ShowDoc(Protocol):
     def __call__(self, obj: Model, state: State, notebook_handle: CommsHandle) -> CommsHandle: ...
 
 class ShowApp(Protocol):
-    def __call__(self, app: Application, state: State, notebook_url: str, **kw: Any) -> None: ...
+    def __call__(self, app: Application, state: State, notebook_url: str | ProxyUrlFunc, **kw: Any) -> None: ...
 
 class Hooks(TypedDict):
     load: Load
@@ -498,7 +504,16 @@ def publish_display_data(data: dict[str, Any], metadata: dict[Any, Any] | None =
     from IPython.display import publish_display_data
     publish_display_data(data, metadata, transient=transient, **kwargs)
 
-def show_app(app: Application, state: State, notebook_url: str | Callable[[int | None], str], port: int = 0, **kw: Any) -> None:
+
+ProxyUrlFunc: TypeAlias = Callable[[Union[int, None]], str]
+
+def show_app(
+        app: Application,
+        state: State,
+        notebook_url: str | ProxyUrlFunc = DEFAULT_JUPYTER_URL,
+        port: int = 0,
+        **kw: Any,
+) -> None:
     ''' Embed a Bokeh server application in a Jupyter Notebook output cell.
 
     Args:
@@ -519,6 +534,11 @@ def show_app(app: Application, state: State, notebook_url: str | Callable[[int |
             the callable must generate the server URL, otherwise if passed
             None, it must generate the origin URL for the server.
 
+            If the environment variable JUPYTER_BOKEH_EXTERNAL_URL is set
+            to the external URL of a JupyterHub, notebook_url is overridden
+            with a callable which enables Bokeh to traverse the JupyterHub
+            proxy without specifying this parameter.
+
         port (int) :
             A port for the embedded server will listen on.
 
@@ -539,6 +559,8 @@ def show_app(app: Application, state: State, notebook_url: str | Callable[[int |
 
     loop = IOLoop.current()
 
+    notebook_url = _update_notebook_url_from_env(notebook_url)
+
     if callable(notebook_url):
         origin = notebook_url(None)
     else:
@@ -640,6 +662,70 @@ def _server_url(url: str, port: int | None) -> str:
     else:
         return f"http://{url.split(':')[0]}{port_}{'/'}"
 
+
+def _remote_jupyter_proxy_url(port: int | None) -> str:
+    """ Callable to configure Bokeh's show method when a proxy must be
+    configured. If port is None we're asking about the URL
+    for the origin header.
+
+    Taken from documentation here:
+
+       https://docs.bokeh.org/en/latest/docs/user_guide/output/jupyter.html#jupyterhub
+
+    and made an implicit override when JUPYTER_BOKEH_EXTERNAL_URL is defined in
+    a user's environment to the external hostname of the hub, e.g. https://our-hub.edu
+
+    Args:
+       port (int):
+           random port generated by bokeh to avoid re-using recently closed ports
+
+       Returns:
+           str:
+               URL capable of traversing the JupyterHub proxy to return to this notebook session.
+    """
+    base_url = os.environ['JUPYTER_BOKEH_EXTERNAL_URL']
+    host = urllib.parse.urlparse(base_url).netloc
+
+    # If port is None we're asking for the URL origin
+    # so return the public hostname.
+    if port is None:
+        return host
+
+    service_url_path = os.environ['JUPYTERHUB_SERVICE_PREFIX']
+    proxy_url_path = f'proxy/{port}'
+
+    user_url = urllib.parse.urljoin(base_url, service_url_path)
+    full_url = urllib.parse.urljoin(user_url, proxy_url_path)
+    return full_url
+
+
+def _update_notebook_url_from_env(notebook_url: str | ProxyUrlFunc) -> str | ProxyUrlFunc:
+    """If the environment variable ``JUPYTER_BOKEH_EXTERNAL_URL`` is defined, returns a function which
+    generates URLs which can traverse the JupyterHub proxy.  Otherwise returns ``notebook_url`` unmodified.
+
+    A warning is issued if ``notebook_url`` is not the default and
+    ``JUPYTER_BOKEH_EXTERNAL_URL`` is also defined since setting the
+    environment variable makes specifying ``notebook_url`` irrelevant.
+
+    Args:
+       notebook_url (str | ProxyUrlFunc):
+          Either a URL string which defaults or a function that given a port
+          number will generate a URL suitable for traversing the JupyterHub proxy.
+
+    Returns:
+       str | ProxyUrlFunc
+          Either a URL string or a function that generates a URL string given a port number.  The
+          latter function may be user supplied as the input parameter or defined internally by Bokeh
+          when ``JUPYER_BOKEH_EXTERNAL_URL`` is set.
+
+    """
+    if os.environ.get("JUPYTER_BOKEH_EXTERNAL_URL"):
+        if notebook_url != DEFAULT_JUPYTER_URL:
+            log.warning("Environment var 'JUPYTER_BOKEH_EXTERNAL_URL' is defined. Ignoring 'notebook_url' parameter.")
+        return _remote_jupyter_proxy_url
+    else:
+        return notebook_url
+
 #-----------------------------------------------------------------------------
 # Code
 #-----------------------------------------------------------------------------
