@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -29,6 +29,7 @@ from typing import (
     Callable,
     Iterable,
     Iterator,
+    Literal,
     Sequence,
     TypeVar,
     Union,
@@ -75,6 +76,9 @@ __all__ = (
     'Spacer',
 )
 
+if TYPE_CHECKING:
+    ToolbarOptions = Literal["logo", "autohide", "active_drag", "active_inspect", "active_scroll", "active_tap", "active_multi"]
+
 #-----------------------------------------------------------------------------
 # General API
 #-----------------------------------------------------------------------------
@@ -193,7 +197,7 @@ def gridplot(
         ncols: int | None = None,
         width: int | None = None,
         height: int | None = None,
-        toolbar_options: Any = None, # TODO
+        toolbar_options: dict[ToolbarOptions, Any] | None = None,
         merge_tools: bool = True) -> GridPlot:
     ''' Create a grid of plots rendered on separate canvases.
 
@@ -293,7 +297,7 @@ def gridplot(
             else:
                 raise ValueError("Only UIElement and LayoutDOM items can be inserted into a grid")
 
-    def merge(cls: type[Tool], group: list[Tool]):
+    def merge(cls: type[Tool], group: list[Tool]) -> Tool | ToolProxy | None:
         if issubclass(cls, (SaveTool, CopyTool, ExamineTool, FullscreenTool)):
             return cls()
         else:
@@ -308,14 +312,17 @@ def gridplot(
         tools = group_tools(tools, merge=merge)
 
     logos = [ toolbar.logo for toolbar in toolbars ]
+    autohides = [ toolbar.autohide for toolbar in toolbars ]
     active_drags = [ toolbar.active_drag for toolbar in toolbars ]
     active_inspects = [ toolbar.active_inspect for toolbar in toolbars ]
     active_scrolls = [ toolbar.active_scroll for toolbar in toolbars ]
     active_taps = [ toolbar.active_tap for toolbar in toolbars ]
     active_multis = [ toolbar.active_multi for toolbar in toolbars ]
 
-    T = TypeVar("T")
-    def assert_unique(values: list[T], name: str) -> T | UndefinedType:
+    V = TypeVar("V")
+    def assert_unique(values: list[V], name: ToolbarOptions) -> V | UndefinedType:
+        if name in toolbar_options:
+            return toolbar_options[name]
         n = len(set(values))
         if n == 0:
             return Undefined
@@ -324,6 +331,7 @@ def gridplot(
         return values[-1]
 
     logo = assert_unique(logos, "logo")
+    autohide = assert_unique(autohides, "autohide")
     active_drag = assert_unique(active_drags, "active_drag")
     active_inspect = assert_unique(active_inspects, "active_inspect")
     active_scroll = assert_unique(active_scrolls, "active_scroll")
@@ -333,12 +341,12 @@ def gridplot(
     toolbar = Toolbar(
         tools=tools,
         logo=logo,
+        autohide=autohide,
         active_drag=active_drag,
         active_inspect=active_inspect,
         active_scroll=active_scroll,
         active_tap=active_tap,
         active_multi=active_multi,
-        **toolbar_options,
     )
 
     gp = GridPlot(
