@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -23,6 +23,7 @@ log = logging.getLogger(__name__)
 from . import (
     annotation,
     arrows,
+    dimensional,
     geometry,
     html,
     labels,
@@ -30,6 +31,7 @@ from . import (
 )
 from .annotation import *
 from .arrows import *
+from .dimensional import *
 from .geometry import *
 from .html import *
 from .labels import *
@@ -42,6 +44,7 @@ from .legends import *
 __all__ = (
     *annotation.__all__,
     *arrows.__all__,
+    *dimensional.__all__,
     *geometry.__all__,
     *html.__all__,
     *labels.__all__,
