@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -22,7 +22,7 @@ log = logging.getLogger(__name__)
 #-----------------------------------------------------------------------------
 
 # Bokeh imports
-from ..core.enums import LabelOrientation
+from ..core.enums import Align, LabelOrientation
 from ..core.has_props import abstract
 from ..core.properties import (
     Auto,
@@ -44,7 +44,7 @@ from ..core.properties import (
     TextLike,
     Tuple,
 )
-from ..core.property_mixins import ScalarLineProps, ScalarTextProps
+from ..core.property_mixins import ScalarFillProps, ScalarLineProps, ScalarTextProps
 from .formatters import (
     BasicTickFormatter,
     CategoricalTickFormatter,
@@ -93,6 +93,23 @@ class Axis(GuideRenderer):
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
+    # TODO: Enum(0, 1) instead of Int
+    dimension = Either(Auto, Int, default="auto", help="""
+    This allows to override the inferred dimensions in contexts that
+    support this. This property has no effect when an axes is used
+    as a frame axis.
+
+    .. note::
+        This property is experimental and may change at any point.
+    """)
+
+    face = Either(Auto, Enum("front", "back"))(default="auto", help="""
+    The direction toward which the axis will face.
+
+    .. note::
+        This property is experimental and may change at any point.
+    """)
+
     bounds = Either(Auto, Tuple(Float, Float), Tuple(Datetime, Datetime), help="""
     Bounds for the rendered axis. If unset, the axis will span the
     entire plot in the given dimension.
@@ -143,6 +160,10 @@ class Axis(GuideRenderer):
     is supplied, the angle of the text is measured from horizontal.
     """)
 
+    axis_label_align = Enum(Align, default="center", help="""
+    The alignment of axis label along the axis.
+    """)
+
     axis_label_props = Include(ScalarTextProps, prefix="axis_label", help="""
     The {prop} of the axis label.
     """)
@@ -222,6 +243,12 @@ class Axis(GuideRenderer):
         inside the central plot area.
     """)
 
+    background_props = Include(ScalarFillProps, prefix="background", help="""
+    The {prop} of the axis background.
+    """)
+
+    background_fill_color = Override(default=None)
+
 @abstract
 class ContinuousAxis(Axis):
     ''' A base class for all numeric, non-categorical axes types.
