@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -325,7 +325,7 @@ class LogTickFormatter(TickFormatter):
 
     min_exponent = Int(0, help="""
     Minimum exponent to format in scientific notation. If not zero
-    all ticks in range from base^-min_expont to base^min_exponent
+    all ticks in range from base^-min_exponent to base^min_exponent
     are displayed without exponential notation.
     """)
 
@@ -367,21 +367,21 @@ class CustomJSTickFormatter(TickFormatter):
 
     Additionally available variables are:
 
-      * ``ticks``, an array of all axis ticks as positioned by the ticker,
-      * ``index``, the position of ``tick`` within ``ticks``, and
-      * the keys of ``args`` mapping, if any.
+    * ``ticks``, an array of all axis ticks as positioned by the ticker,
+    * ``index``, the position of ``tick`` within ``ticks``, and
+    * the keys of ``args`` mapping, if any.
 
     Finding yourself needing to cache an expensive ``ticks``-dependent
     computation, you can store it on the ``this`` variable.
 
-    Example:
+    **Example**
 
-        .. code-block:: javascript
+    .. code-block:: javascript
 
-            code = '''
-            this.precision = this.precision || (ticks.length > 5 ? 1 : 2);
-            return Math.floor(tick) + " + " + (tick % 1).toFixed(this.precision);
-            '''
+        code = '''
+        this.precision = this.precision || (ticks.length > 5 ? 1 : 2);
+        return Math.floor(tick) + " + " + (tick % 1).toFixed(this.precision);
+        '''
     """)
 
 def FuncTickFormatter(*args, **kw):
