@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -408,10 +408,12 @@ class Plot(LayoutDOM):
                     tile_source = "esri_worldimagery"
                 if tile_source == "osm":
                     tile_source = "openstreetmap_mapnik"
-
+                if tile_source.startswith("stamen"):
+                    tile_source = f"stadia.{tile_source}"
                 if "retina" in tile_source:
                     tile_source = tile_source.replace("retina", "")
                     retina = True
+
                 selected_provider = xyzservices.providers.query_name(tile_source)
 
             scale_factor = "@2x" if retina else None
