@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -42,6 +42,7 @@ log = logging.getLogger(__name__)
 # Standard library imports
 import difflib
 import typing as tp
+from math import nan
 from typing import Literal
 
 # Bokeh imports
@@ -74,6 +75,7 @@ from ..core.properties import (
     InstanceDefault,
     Int,
     List,
+    NonNegative,
     Null,
     Nullable,
     Override,
@@ -83,33 +85,34 @@ from ..core.properties import (
     String,
     Struct,
     Tuple,
+    TypeOfAttr,
 )
 from ..core.property.struct import Optional
 from ..core.validation import error
-from ..core.validation.errors import (
-    INCOMPATIBLE_BOX_EDIT_RENDERER,
-    INCOMPATIBLE_LINE_EDIT_INTERSECTION_RENDERER,
-    INCOMPATIBLE_LINE_EDIT_RENDERER,
-    INCOMPATIBLE_POINT_DRAW_RENDERER,
-    INCOMPATIBLE_POLY_DRAW_RENDERER,
-    INCOMPATIBLE_POLY_EDIT_RENDERER,
-    INCOMPATIBLE_POLY_EDIT_VERTEX_RENDERER,
-    NO_RANGE_TOOL_RANGES,
-)
+from ..core.validation.errors import NO_RANGE_TOOL_RANGES
 from ..model import Model
 from ..util.strings import nice_join
 from .annotations import BoxAnnotation, PolyAnnotation, Span
 from .callbacks import Callback
+from .coordinates import (
+    FrameBottom,
+    FrameLeft,
+    FrameRight,
+    FrameTop,
+)
 from .dom import Template
 from .glyphs import (
+    HStrip,
     Line,
     LineGlyph,
+    LRTBGlyph,
     MultiLine,
     Patches,
     Rect,
+    VStrip,
     XYGlyph,
 )
-from .ranges import Range1d
+from .ranges import Range
 from .renderers import DataRenderer, GlyphRenderer
 from .ui import UIElement
 
@@ -163,6 +166,10 @@ __all__ = (
 # General API
 #-----------------------------------------------------------------------------
 
+def GlyphRendererOf(*types: type[Model]):
+    """ Constraints ``GlyphRenderer.glyph`` to the given type or types. """
+    return TypeOfAttr(Instance(GlyphRenderer), "glyph", Either(*(Instance(tp) for tp in types)))
+
 @abstract
 class Tool(Model):
     ''' A base class for all interactive tool types.
@@ -172,6 +179,7 @@ class Tool(Model):
     # explicit __init__ to support Init signatures
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
+
     #Image has to be first! see #12775, temporary fix
     icon = Nullable(Either(Image, Enum(ToolIcon), Regex(r"^\.")), help="""
     An icon to display in the toolbar.
@@ -288,7 +296,7 @@ class SelectTool(GestureTool):
         super().__init__(*args, **kwargs)
 
     renderers = Either(Auto, List(Instance(DataRenderer)), default="auto", help="""
-    An explicit list of renderers to hit test against. If unset, defaults to
+    A list of renderers to hit test against. If unset, defaults to
     all renderers on a plot.
     """)
 
@@ -321,6 +329,12 @@ class RegionSelectTool(SelectTool):
     the annotation, to allow to modify the selection.
     """)
 
+    greedy = Bool(default=False, help="""
+    Defines whether a hit against a glyph requires full enclosure within
+    the selection region (non-greedy) or only an intersection (greedy)
+    (i.e. at least one point within the region).
+    """)
+
 @abstract
 class InspectTool(GestureTool):
     ''' A base class for tools that perform "inspections", e.g. ``HoverTool``.
@@ -415,12 +429,22 @@ class PanTool(Drag):
     height of the plot.
     """)
 
-DEFAULT_RANGE_OVERLAY = InstanceDefault(BoxAnnotation,
+# TODO InstanceDefault() doesn't allow for lazy argument evaluation
+# DEFAULT_RANGE_OVERLAY = InstanceDefault(BoxAnnotation,
+DEFAULT_RANGE_OVERLAY = lambda: BoxAnnotation(
     syncable=False,
     level="overlay",
     visible=True,
     editable=True,
     propagate_hover=True,
+    left=nan,
+    right=nan,
+    top=nan,
+    bottom=nan,
+    left_limit=FrameLeft(),
+    right_limit=FrameRight(),
+    top_limit=FrameTop(),
+    bottom_limit=FrameBottom(),
     fill_color="lightgrey",
     fill_alpha=0.5,
     line_color="black",
@@ -451,12 +475,12 @@ class RangeTool(Tool):
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
-    x_range = Nullable(Instance(Range1d), help="""
+    x_range = Nullable(Instance(Range), help="""
     A range synchronized to the x-dimension of the overlay. If None, the overlay
     will span the entire x-dimension.
     """)
 
-    y_range = Nullable(Instance(Range1d), help="""
+    y_range = Nullable(Instance(Range), help="""
     A range synchronized to the y-dimension of the overlay. If None, the overlay
     will span the entire y-dimension.
     """)
@@ -532,6 +556,7 @@ class WheelZoomTool(Scroll):
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
+    # ZoomBaseTool common {
     dimensions = Enum(Dimensions, default="both", help="""
     Which dimensions the wheel zoom tool is constrained to act in. By default
     the wheel zoom tool will zoom in any dimension, but can be configured to
@@ -539,6 +564,18 @@ class WheelZoomTool(Scroll):
     the height of the plot.
     """)
 
+    renderers = Either(Auto, List(Instance(DataRenderer)), default="auto", help="""
+    Restrict zoom to ranges used by the provided data renderers. If ``"auto"``
+    then all ranges provided by the cartesian frame will be used.
+    """)
+
+    level = NonNegative(Int, default=0, help="""
+    When working with composite scales (sub-coordinates), this property
+    allows to configure which set of ranges to scale. The default is to
+    scale top-level (frame) ranges.
+    """)
+    # }
+
     maintain_focus = Bool(default=True, help="""
     If True, then hitting a range bound in any one dimension will prevent all
     further zooming all dimensions. If False, zooming can continue
@@ -802,6 +839,10 @@ DEFAULT_BOX_ZOOM_OVERLAY = InstanceDefault(BoxAnnotation,
     level="overlay",
     visible=False,
     editable=False,
+    left=nan,
+    right=nan,
+    top=nan,
+    bottom=nan,
     top_units="canvas",
     left_units="canvas",
     bottom_units="canvas",
@@ -819,6 +860,10 @@ DEFAULT_BOX_SELECT_OVERLAY = InstanceDefault(BoxAnnotation,
     level="overlay",
     visible=False,
     editable=True,
+    left=nan,
+    right=nan,
+    top=nan,
+    bottom=nan,
     top_units="data",
     left_units="data",
     bottom_units="data",
@@ -834,7 +879,7 @@ DEFAULT_BOX_SELECT_OVERLAY = InstanceDefault(BoxAnnotation,
 class BoxZoomTool(Drag):
     ''' *toolbar icon*: |box_zoom_icon|
 
-    The box zoom tool allows users to define a rectangular egion of a Plot to
+    The box zoom tool allows users to define a rectangular region of a Plot to
     zoom to by dragging he mouse or a finger over the plot region. The end of
     the drag event indicates the selection region is ready.
 
@@ -894,6 +939,24 @@ class ZoomBaseTool(PlotActionTool):
     then all ranges provided by the cartesian frame will be used.
     """)
 
+    # TODO ZoomInTool dimensions should probably be constrained to be the same as ZoomOutTool
+    dimensions = Enum(Dimensions, default="both", help="""
+    Which dimensions the zoom tool is constrained to act in. By default
+    the tool will zoom in any dimension, but can be configured to only
+    zoom horizontally across the width of the plot, or vertically across
+    the height of the plot.
+    """)
+
+    factor = Percent(default=0.1, help="""
+    Percentage of the range to zoom for each usage of the tool.
+    """)
+
+    level = NonNegative(Int, default=0, help="""
+    When working with composite scales (sub-coordinates), this property
+    allows to configure which set of ranges to scale. The default is to
+    scale top-level (frame) ranges.
+    """)
+
 class ZoomInTool(ZoomBaseTool):
     ''' *toolbar icon*: |zoom_in_icon|
 
@@ -910,18 +973,6 @@ class ZoomInTool(ZoomBaseTool):
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
-    # TODO ZoomInTool dimensions should probably be constrained to be the same as ZoomOutTool
-    dimensions = Enum(Dimensions, default="both", help="""
-    Which dimensions the zoom-in tool is constrained to act in. By default the
-    zoom-in zoom tool will zoom in any dimension, but can be configured to only
-    zoom horizontally across the width of the plot, or vertically across the
-    height of the plot.
-    """)
-
-    factor = Percent(default=0.1, help="""
-    Percentage to zoom for each click of the zoom-in tool.
-    """)
-
 class ZoomOutTool(ZoomBaseTool):
     ''' *toolbar icon*: |zoom_out_icon|
 
@@ -938,22 +989,11 @@ class ZoomOutTool(ZoomBaseTool):
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
-    dimensions = Enum(Dimensions, default="both", help="""
-    Which dimensions the zoom-out tool is constrained to act in. By default the
-    zoom-out tool will zoom in any dimension, but can be configured to only
-    zoom horizontally across the width of the plot, or vertically across the
-    height of the plot.
-    """)
-
-    factor = Percent(default=0.1, help="""
-    Percentage to zoom for each click of the zoom-in tool.
-    """)
-
     maintain_focus = Bool(default=True, help="""
-    If True, then hitting a range bound in any one dimension will prevent all
-    further zooming all dimensions. If False, zooming can continue
-    independently in any dimension that has not yet reached its bounds, even if
-    that causes overall focus or aspect ratio to change.
+    If ``True``, then hitting a range bound in any one dimension will prevent
+    all further zooming in all dimensions. If ``False``, zooming can continue
+    independently in any dimension that has not yet reached its bounds, even
+    if that causes overall focus or aspect ratio to change.
     """)
 
 class BoxSelectTool(Drag, RegionSelectTool):
@@ -1161,13 +1201,13 @@ class CustomJSHover(Model):
     The snippet will be made into the body of a function and therefore requires
     a return statement.
 
-    Example:
+    **Example**
 
-        .. code-block:: javascript
+    .. code-block:: javascript
 
-            code = '''
-            return value + " total"
-            '''
+        code = '''
+        return value + " total"
+        '''
     """)
 
 class HoverTool(InspectTool):
@@ -1214,19 +1254,19 @@ class HoverTool(InspectTool):
 
     Hover tool does not currently work with the following glyphs:
 
-        .. hlist::
-            :columns: 3
+    .. hlist::
+        :columns: 3
 
-            * annulus
-            * arc
-            * bezier
-            * image_url
-            * oval
-            * patch
-            * quadratic
-            * ray
-            * step
-            * text
+        * annulus
+        * arc
+        * bezier
+        * image_url
+        * oval
+        * patch
+        * quadratic
+        * ray
+        * step
+        * text
 
     .. |hover_icon| image:: /_images/icons/Hover.png
         :height: 24px
@@ -1239,7 +1279,7 @@ class HoverTool(InspectTool):
         super().__init__(*args, **kwargs)
 
     renderers = Either(Auto, List(Instance(DataRenderer)), default="auto", help="""
-    An explicit list of renderers to hit test against. If unset, defaults to
+    A list of renderers to hit test against. If unset, defaults to
     all renderers on a plot.
     """)
 
@@ -1488,15 +1528,7 @@ class EditTool(GestureTool):
     the color column will be filled with the defined empty value.
     """)
 
-    renderers = List(Instance(GlyphRenderer), help="""
-    An explicit list of renderers corresponding to glyphs that may be edited.
-
-    .. note::
-        The kind of renderer will typically depend on the specific type of the
-        edit tool subclass. For instance, ``PointDrawTool`` expects renderers
-        for ``Scatter`` glyphs, while ``BoxEditTool`` expects renderers for
-        ``Rect`` glyphs, etc.
-    """)
+    # TODO abstract renderers = List(Instance(GlyphRenderer & ...))
 
 @abstract
 class PolyTool(EditTool):
@@ -1506,26 +1538,19 @@ class PolyTool(EditTool):
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
-    vertex_renderer = Nullable(Instance(GlyphRenderer), help="""
+    vertex_renderer = Nullable(GlyphRendererOf(XYGlyph), help="""
     The renderer used to render the vertices of a selected line or polygon.
     """)
 
-    @error(INCOMPATIBLE_POLY_EDIT_VERTEX_RENDERER)
-    def _check_compatible_vertex_renderer(self):
-        if self.vertex_renderer is None:
-            return
-        glyph = self.vertex_renderer.glyph
-        if not isinstance(glyph, XYGlyph):
-            return "glyph type %s found." % type(glyph).__name__
-
 class BoxEditTool(EditTool, Drag, Tap):
     ''' *toolbar icon*: |box_edit_icon|
 
-    Allows drawing, dragging and deleting ``Rect`` glyphs on one or more
-    renderers by editing the underlying ``ColumnDataSource`` data. Like other
-    drawing tools, the renderers that are to be edited must be supplied
-    explicitly as a list. When drawing a new box the data will always be added
-    to the ``ColumnDataSource`` on the first supplied renderer.
+    Allows drawing, dragging and deleting box-like glyphs (e.g. ``Block``,
+    ``Rect``, ``HStrip``) on one or more renderers by editing the underlying
+    ``ColumnDataSource`` data. Like other drawing tools, the renderers that
+    are to be edited must be supplied explicitly as a list. When drawing a
+    new box the data will always be added to the ``ColumnDataSource`` on
+    the first supplied renderer.
 
     The tool will modify the columns on the data source corresponding to the
     ``x``, ``y``, ``width`` and ``height`` values of the glyph. Any additional
@@ -1562,6 +1587,10 @@ class BoxEditTool(EditTool, Drag, Tap):
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
+    renderers = List(GlyphRendererOf(LRTBGlyph, Rect, HStrip, VStrip), help="""
+    A list of renderers corresponding to glyphs that may be edited.
+    """)
+
     dimensions = Enum(Dimensions, default="both", help="""
     Which dimensions the box drawing is to be free in. By default, users may
     freely draw boxes with any dimensions. If only "width" is set, the box will
@@ -1577,16 +1606,6 @@ class BoxEditTool(EditTool, Drag, Tap):
     will be dropped to make space for the new box being added.
     """)
 
-    @error(INCOMPATIBLE_BOX_EDIT_RENDERER)
-    def _check_compatible_renderers(self):
-        incompatible_renderers = []
-        for renderer in self.renderers:
-            if not isinstance(renderer.glyph, Rect):
-                incompatible_renderers.append(renderer)
-        if incompatible_renderers:
-            glyph_types = ', '.join(type(renderer.glyph).__name__ for renderer in incompatible_renderers)
-            return "%s glyph type(s) found." % glyph_types
-
 class PointDrawTool(EditTool, Drag, Tap):
     ''' *toolbar icon*: |point_draw_icon|
 
@@ -1628,6 +1647,10 @@ class PointDrawTool(EditTool, Drag, Tap):
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
+    renderers = List(GlyphRendererOf(XYGlyph), help="""
+    A list of renderers corresponding to glyphs that may be edited.
+    """)
+
     add = Bool(default=True, help="""
     Enables adding of new points on tap events.
     """)
@@ -1642,16 +1665,6 @@ class PointDrawTool(EditTool, Drag, Tap):
     will be dropped to make space for the new point.
     """)
 
-    @error(INCOMPATIBLE_POINT_DRAW_RENDERER)
-    def _check_compatible_renderers(self):
-        incompatible_renderers = []
-        for renderer in self.renderers:
-            if not isinstance(renderer.glyph, XYGlyph):
-                incompatible_renderers.append(renderer)
-        if incompatible_renderers:
-            glyph_types = ', '.join(type(renderer.glyph).__name__ for renderer in incompatible_renderers)
-            return "%s glyph type(s) found." % glyph_types
-
 class PolyDrawTool(PolyTool, Drag, Tap):
     ''' *toolbar icon*: |poly_draw_icon|
 
@@ -1692,6 +1705,10 @@ class PolyDrawTool(PolyTool, Drag, Tap):
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
+    renderers = List(GlyphRendererOf(MultiLine, Patches), help="""
+    A list of renderers corresponding to glyphs that may be edited.
+    """)
+
     drag = Bool(default=True, help="""
     Enables dragging of existing patches and multi-lines on pan events.
     """)
@@ -1703,16 +1720,6 @@ class PolyDrawTool(PolyTool, Drag, Tap):
     patch or multi-line.
     """)
 
-    @error(INCOMPATIBLE_POLY_DRAW_RENDERER)
-    def _check_compatible_renderers(self):
-        incompatible_renderers = []
-        for renderer in self.renderers:
-            if not isinstance(renderer.glyph, (MultiLine, Patches)):
-                incompatible_renderers.append(renderer)
-        if incompatible_renderers:
-            glyph_types = ', '.join(type(renderer.glyph).__name__ for renderer in incompatible_renderers)
-            return "%s glyph type(s) found." % glyph_types
-
 class FreehandDrawTool(EditTool, Drag, Tap):
     ''' *toolbar icon*: |freehand_draw_icon|
 
@@ -1741,6 +1748,10 @@ class FreehandDrawTool(EditTool, Drag, Tap):
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
+    renderers = List(GlyphRendererOf(MultiLine, Patches), help="""
+    A list of renderers corresponding to glyphs that may be edited.
+    """)
+
     num_objects = Int(default=0, help="""
     Defines a limit on the number of patches or multi-lines that can be drawn.
     By default there is no limit on the number of objects, but if enabled the
@@ -1748,16 +1759,6 @@ class FreehandDrawTool(EditTool, Drag, Tap):
     reached.
     """)
 
-    @error(INCOMPATIBLE_POLY_DRAW_RENDERER)
-    def _check_compatible_renderers(self):
-        incompatible_renderers = []
-        for renderer in self.renderers:
-            if not isinstance(renderer.glyph, (MultiLine, Patches)):
-                incompatible_renderers.append(renderer)
-        if incompatible_renderers:
-            glyph_types = ', '.join(type(renderer.glyph).__name__ for renderer in incompatible_renderers)
-            return "%s glyph type(s) found." % glyph_types
-
 class PolyEditTool(PolyTool, Drag, Tap):
     ''' *toolbar icon*: |poly_edit_icon|
 
@@ -1795,17 +1796,9 @@ class PolyEditTool(PolyTool, Drag, Tap):
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
-    @error(INCOMPATIBLE_POLY_EDIT_RENDERER)
-    def _check_compatible_renderers(self):
-        incompatible_renderers = []
-        for renderer in self.renderers:
-            if not isinstance(renderer.glyph, (MultiLine, Patches)):
-                incompatible_renderers.append(renderer)
-        if incompatible_renderers:
-            glyph_types = ', '.join(type(renderer.glyph).__name__
-                                    for renderer in incompatible_renderers)
-            return "%s glyph type(s) found." % glyph_types
-
+    renderers = List(GlyphRendererOf(MultiLine, Patches), help="""
+    A list of renderers corresponding to glyphs that may be edited.
+    """)
 
 class LineEditTool(EditTool, Drag, Tap):
     ''' *toolbar icon*: |line_edit_icon|
@@ -1837,7 +1830,11 @@ class LineEditTool(EditTool, Drag, Tap):
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
-    intersection_renderer = Instance(GlyphRenderer, help="""
+    renderers = List(GlyphRendererOf(Line), help="""
+    A list of renderers corresponding to glyphs that may be edited.
+    """)
+
+    intersection_renderer = GlyphRendererOf(LineGlyph)(help="""
     The renderer used to render the intersections of a selected line
     """)
 
@@ -1848,24 +1845,6 @@ class LineEditTool(EditTool, Drag, Tap):
     plot, or vertical across the height of the plot.
     """)
 
-    @error(INCOMPATIBLE_LINE_EDIT_INTERSECTION_RENDERER)
-    def _check_compatible_intersection_renderer(self):
-        glyph = self.intersection_renderer.glyph
-        if not isinstance(glyph, LineGlyph):
-            return "glyph type %s found." % type(glyph).__name__
-
-    @error(INCOMPATIBLE_LINE_EDIT_RENDERER)
-    def _check_compatible_renderers(self):
-        incompatible_renderers = []
-        for renderer in self.renderers:
-            if not isinstance(renderer.glyph, (Line,)):
-                incompatible_renderers.append(renderer)
-        if incompatible_renderers:
-            glyph_types = ', '.join(type(renderer.glyph).__name__
-                                    for renderer in incompatible_renderers)
-            return "%s glyph type(s) found." % glyph_types
-
-#
 #-----------------------------------------------------------------------------
 # Dev API
 #-----------------------------------------------------------------------------
