@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -32,15 +32,16 @@ from ...core.properties import (
     Enum,
     Instance,
     List,
-    Null,
     Nullable,
     Override,
+    Required,
     String,
     Tuple,
 )
 from ...events import ButtonClick, MenuItemClick
 from ..callbacks import Callback
-from .icons import AbstractIcon
+from ..ui.icons import BuiltinIcon, Icon
+from ..ui.tooltips import Tooltip
 from .widget import Widget
 
 if TYPE_CHECKING:
@@ -55,6 +56,7 @@ __all__ = (
     'Button',
     'ButtonLike',
     'Dropdown',
+    'HelpButton',
     'Toggle',
 )
 
@@ -68,8 +70,25 @@ class ButtonLike(HasProps):
 
     '''
 
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
     button_type = Enum(ButtonType, help="""
-    A style for the button, signifying it's role.
+    A style for the button, signifying it's role. Possible values are one of the
+    following:
+
+    .. bokeh-plot::
+        :source-position: none
+
+        from bokeh.core.enums import ButtonType
+        from bokeh.io import show
+        from bokeh.layouts import column
+        from bokeh.models import Button
+
+        show(column(
+            [Button(label=button_type, button_type=button_type) for button_type in ButtonType]
+            ))
     """)
 
 @abstract
@@ -78,12 +97,18 @@ class AbstractButton(Widget, ButtonLike):
 
     '''
 
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
     label = String("Button", help="""
     The text label for the button to display.
     """)
 
-    icon = Nullable(Instance(AbstractIcon), help="""
-    An optional image appearing to the left of button's text.
+    icon = Nullable(Instance(Icon), help="""
+    An optional image appearing to the left of button's text. An instance of
+    :class:`~bokeh.models.Icon` (such as :class:`~bokeh.models.BuiltinIcon`,
+    :class:`~bokeh.models.SVGIcon`, or :class:`~bokeh.models.TablerIcon`).`
     """)
 
 #-----------------------------------------------------------------------------
@@ -95,6 +120,10 @@ class Button(AbstractButton):
 
     '''
 
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
     label = Override(default="Button")
 
     def on_click(self, handler: EventCallback) -> None:
@@ -118,11 +147,14 @@ class Toggle(AbstractButton):
 
     '''
 
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
     label = Override(default="Toggle")
 
     active = Bool(False, help="""
-    The initial state of a button. Also used to trigger ``on_click`` event
-    handler.
+    The state of the toggle button.
     """)
 
     def on_click(self, handler: Callable[[bool], None]) -> None:
@@ -133,7 +165,6 @@ class Toggle(AbstractButton):
 
         Returns:
             None
-
         """
         self.on_change('active', lambda attr, old, new: handler(new))
 
@@ -146,12 +177,16 @@ class Dropdown(AbstractButton):
 
     '''
 
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
     label = Override(default="Dropdown")
 
     split = Bool(default=False, help="""
     """)
 
-    menu = List(Either(Null, String, Tuple(String, Either(String, Instance(Callback)))), help="""
+    menu = List(Nullable(Either(String, Tuple(String, Either(String, Instance(Callback))))), help="""
     Button's dropdown menu consisting of entries containing item's text and
     value name. Use ``None`` as a menu separator.
     """)
@@ -174,6 +209,26 @@ class Dropdown(AbstractButton):
         self.js_on_event(ButtonClick, handler)
         self.js_on_event(MenuItemClick, handler)
 
+class HelpButton(AbstractButton):
+    """ A button with a help symbol that displays additional text when hovered
+    over or clicked.
+    """
+
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+    tooltip = Required(Instance(Tooltip), help="""
+    A tooltip with plain text or rich HTML contents, providing general help or
+    description of a widget's or component's function.
+    """)
+
+    label = Override(default="")
+
+    icon = Override(default=lambda: BuiltinIcon("help", size=18))
+
+    button_type = Override(default="default")
+
 #-----------------------------------------------------------------------------
 # Private API
 #-----------------------------------------------------------------------------
