@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -22,8 +22,7 @@ log = logging.getLogger(__name__)
 
 # Standard library imports
 import numbers
-import typing as tp
-from datetime import date, datetime
+from datetime import date, datetime, timezone
 
 # Bokeh imports
 from ...core.has_props import abstract
@@ -36,13 +35,15 @@ from ...core.properties import (
     Float,
     Instance,
     Int,
-    NonNullable,
     Nullable,
     Override,
     Readonly,
+    Required,
     String,
     Tuple,
 )
+from ...core.property.descriptors import UnsetValueError
+from ...core.property.singletons import Undefined
 from ...core.validation import error
 from ...core.validation.errors import EQUAL_SLIDER_START_END
 from ..formatters import TickFormatter
@@ -69,22 +70,35 @@ __all__ = (
 class AbstractSlider(Widget):
     """ """
 
-    def __init__(self, **kwargs) -> None:
-        if 'start' in kwargs and 'end' in kwargs:
-            if kwargs['start'] == kwargs['end']:
-                raise ValueError("Slider 'start' and 'end' cannot be equal.")
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
 
-        if "value" in kwargs and "value_throttled" not in kwargs:
-            kwargs["value_throttled"] = kwargs["value"]
+        try:
+            # synchronize the value of a readonly property `value_throttled`
+            self.lookup("value_throttled")._set(self, Undefined, self.value)
+        except UnsetValueError:
+            pass
+        except AttributeError:
+            # TODO Remove this when proper support for property overrides is
+            # implemented. For now this is required to make defaults' tests
+            # work, because we depend there on model instances to provide
+            # "default" values.
+            pass
 
-        super().__init__(**kwargs)
+    # TODO value = Required(GenericType, help="""
+    # Initial or selected range.
+    # """)
+
+    # TODO value_throttled = Readonly(GenericType, help="""
+    # Initial or selected value, throttled according to report only on mouseup.
+    # """)
 
     orientation = Enum("horizontal", "vertical", help="""
     Orient the slider either horizontally (default) or vertically.
     """)
 
     title = Nullable(String, default="", help="""
-    Slider's label.
+    The slider's label (supports :ref:`math text <ug_styling_mathtext>`).
     """)
 
     show_value = Bool(default=True, help="""
@@ -98,11 +112,14 @@ class AbstractSlider(Widget):
     """)
 
     tooltips = Bool(default=True, help="""
+    Display the slider's current value in a tooltip.
     """)
 
     bar_color = Color(default="#e6e6e6", help="""
     """)
 
+    width = Override(default=300)
+
     @error(EQUAL_SLIDER_START_END)
     def _check_missing_dimension(self):
         if hasattr(self, 'start') and hasattr(self, 'end'):
@@ -116,19 +133,23 @@ class AbstractSlider(Widget):
 class Slider(AbstractSlider):
     """ Slider-based number selection widget. """
 
-    start = NonNullable(Float, help="""
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+    start = Required(Float, help="""
     The minimum allowable value.
     """)
 
-    end = NonNullable(Float, help="""
+    end = Required(Float, help="""
     The maximum allowable value.
     """)
 
-    value = NonNullable(Float, help="""
+    value = Required(Float, help="""
     Initial or selected value.
     """)
 
-    value_throttled = Readonly(NonNullable(Float), help="""
+    value_throttled = Readonly(Required(Float), help="""
     Initial or selected value, throttled according to report only on mouseup.
     """)
 
@@ -141,19 +162,23 @@ class Slider(AbstractSlider):
 class RangeSlider(AbstractSlider):
     """ Range-slider based number range selection widget. """
 
-    value = NonNullable(Tuple(Float, Float), help="""
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+    value = Required(Tuple(Float, Float), help="""
     Initial or selected range.
     """)
 
-    value_throttled = Readonly(NonNullable(Tuple(Float, Float)), help="""
+    value_throttled = Readonly(Required(Tuple(Float, Float)), help="""
     Initial or selected value, throttled according to report only on mouseup.
     """)
 
-    start = NonNullable(Float, help="""
+    start = Required(Float, help="""
     The minimum allowable value.
     """)
 
-    end = NonNullable(Float, help="""
+    end = Required(Float, help="""
     The maximum allowable value.
     """)
 
@@ -166,6 +191,10 @@ class RangeSlider(AbstractSlider):
 class DateSlider(AbstractSlider):
     """ Slider-based date selection widget. """
 
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
     @property
     def value_as_datetime(self) -> datetime | None:
         ''' Convenience property to retrieve the value as a datetime object.
@@ -176,7 +205,7 @@ class DateSlider(AbstractSlider):
             return None
 
         if isinstance(self.value, numbers.Number):
-            return datetime.utcfromtimestamp(self.value / 1000)
+            return datetime.fromtimestamp(self.value / 1000, tz=timezone.utc)
 
         return self.value
 
@@ -190,29 +219,29 @@ class DateSlider(AbstractSlider):
             return None
 
         if isinstance(self.value, numbers.Number):
-            dt = datetime.utcfromtimestamp(self.value / 1000)
+            dt = datetime.fromtimestamp(self.value / 1000, tz=timezone.utc)
             return date(*dt.timetuple()[:3])
 
         return self.value
 
-    value = NonNullable(Datetime, help="""
+    value = Required(Datetime, help="""
     Initial or selected value.
     """)
 
-    value_throttled = Readonly(NonNullable(Datetime), help="""
+    value_throttled = Readonly(Required(Datetime), help="""
     Initial or selected value, throttled to report only on mouseup.
     """)
 
-    start = NonNullable(Datetime, help="""
+    start = Required(Datetime, help="""
     The minimum allowable value.
     """)
 
-    end = NonNullable(Datetime, help="""
+    end = Required(Datetime, help="""
     The maximum allowable value.
     """)
 
     step = Int(default=1, help="""
-    The step between consecutive values.
+    The step between consecutive values, in units of days.
     """)
 
     format = Override(default="%d %b %Y")
@@ -220,8 +249,12 @@ class DateSlider(AbstractSlider):
 class DateRangeSlider(AbstractSlider):
     """ Slider-based date range selection widget. """
 
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
     @property
-    def value_as_datetime(self) -> tp.Tuple[datetime, datetime] | None:
+    def value_as_datetime(self) -> tuple[datetime, datetime] | None:
         ''' Convenience property to retrieve the value tuple as a tuple of
         datetime objects.
 
@@ -231,17 +264,17 @@ class DateRangeSlider(AbstractSlider):
             return None
         v1, v2 = self.value
         if isinstance(v1, numbers.Number):
-            d1 = datetime.utcfromtimestamp(v1 / 1000)
+            d1 = datetime.fromtimestamp(v1 / 1000, tz=timezone.utc)
         else:
             d1 = v1
         if isinstance(v2, numbers.Number):
-            d2 = datetime.utcfromtimestamp(v2 / 1000)
+            d2 = datetime.fromtimestamp(v2 / 1000, tz=timezone.utc)
         else:
             d2 = v2
         return d1, d2
 
     @property
-    def value_as_date(self) -> tp.Tuple[date, date] | None:
+    def value_as_date(self) -> tuple[date, date] | None:
         ''' Convenience property to retrieve the value tuple as a tuple of
         date objects.
 
@@ -251,35 +284,35 @@ class DateRangeSlider(AbstractSlider):
             return None
         v1, v2 = self.value
         if isinstance(v1, numbers.Number):
-            dt = datetime.utcfromtimestamp(v1 / 1000)
+            dt = datetime.fromtimestamp(v1 / 1000, tz=timezone.utc)
             d1 = date(*dt.timetuple()[:3])
         else:
             d1 = v1
         if isinstance(v2, numbers.Number):
-            dt = datetime.utcfromtimestamp(v2 / 1000)
+            dt = datetime.fromtimestamp(v2 / 1000, tz=timezone.utc)
             d2 = date(*dt.timetuple()[:3])
         else:
             d2 = v2
         return d1, d2
 
-    value = NonNullable(Tuple(Datetime, Datetime), help="""
+    value = Required(Tuple(Datetime, Datetime), help="""
     Initial or selected range.
     """)
 
-    value_throttled = Readonly(NonNullable(Tuple(Datetime, Datetime)), help="""
+    value_throttled = Readonly(Required(Tuple(Datetime, Datetime)), help="""
     Initial or selected value, throttled to report only on mouseup.
     """)
 
-    start = NonNullable(Datetime, help="""
+    start = Required(Datetime, help="""
     The minimum allowable value.
     """)
 
-    end = NonNullable(Datetime, help="""
+    end = Required(Datetime, help="""
     The maximum allowable value.
     """)
 
     step = Int(default=1, help="""
-    The step between consecutive values.
+    The step between consecutive values, in units of days.
     """)
 
     format = Override(default="%d %b %Y")
@@ -292,7 +325,7 @@ class DatetimeRangeSlider(AbstractSlider):
         super().__init__(*args, **kwargs)
 
     @property
-    def value_as_datetime(self) -> tp.Tuple[datetime, datetime] | None:
+    def value_as_datetime(self) -> tuple[datetime, datetime] | None:
         ''' Convenience property to retrieve the value tuple as a tuple of
         datetime objects.
         '''
@@ -300,28 +333,28 @@ class DatetimeRangeSlider(AbstractSlider):
             return None
         v1, v2 = self.value
         if isinstance(v1, numbers.Number):
-            d1 = datetime.utcfromtimestamp(v1 / 1000)
+            d1 = datetime.fromtimestamp(v1 / 1000, tz=timezone.utc)
         else:
             d1 = v1
         if isinstance(v2, numbers.Number):
-            d2 = datetime.utcfromtimestamp(v2 / 1000)
+            d2 = datetime.fromtimestamp(v2 / 1000, tz=timezone.utc)
         else:
             d2 = v2
         return d1, d2
 
-    value = NonNullable(Tuple(Datetime, Datetime), help="""
+    value = Required(Tuple(Datetime, Datetime), help="""
     Initial or selected range.
     """)
 
-    value_throttled = Readonly(NonNullable(Tuple(Datetime, Datetime)), help="""
+    value_throttled = Readonly(Required(Tuple(Datetime, Datetime)), help="""
     Initial or selected value, throttled to report only on mouseup.
     """)
 
-    start = NonNullable(Datetime, help="""
+    start = Required(Datetime, help="""
     The minimum allowable value.
     """)
 
-    end = NonNullable(Datetime, help="""
+    end = Required(Datetime, help="""
     The maximum allowable value.
     """)
 
