@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -43,8 +43,15 @@ log = logging.getLogger(__name__)
 # Standard library imports
 import csv
 import xml.etree.ElementTree as et
+from math import nan
 from typing import TYPE_CHECKING, TypedDict
 
+# External imports
+import numpy as np
+
+if TYPE_CHECKING:
+    from numpy.typing import NDArray
+
 # Bokeh imports
 from ..util.sampledata import external_path, open_csv
 
@@ -78,10 +85,8 @@ class CountyData(TypedDict):
     name: str
     detailed_name: str
     state: str
-    lats: list[float]
-    lons: list[float]
-
-nan = float('NaN')
+    lats: NDArray[np.float64]
+    lons: NDArray[np.float64]
 
 def _read_data() -> dict[tuple[State, County], CountyData]:
     '''
@@ -110,8 +115,8 @@ def _read_data() -> dict[tuple[State, County], CountyData]:
                 name = name,
                 detailed_name = det_name,
                 state = state,
-                lats = lats,
-                lons = lons,
+                lats = np.array(lats),
+                lons = np.array(lons),
             )
 
     return data
