@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -429,7 +429,7 @@ class BokehTornado(TornadoApplication):
                 raise RuntimeError("Couldn't find websocket path")
             for r in app_patterns:
                 assert len(r) == 3 # TODO: handle two valued case as well
-                r[2]["bokeh_websocket_path"] = websocket_path # type: ignore[misc] # TODO: possible bug in mypy; pyright supports the assertion
+                r[2]["bokeh_websocket_path"] = websocket_path
 
             all_patterns.extend(app_patterns)
 
@@ -605,20 +605,28 @@ class BokehTornado(TornadoApplication):
         '''
         return self._session_token_expiration
 
-    def resources(self, absolute_url: str | None = None) -> Resources:
+    def resources(self, absolute_url: str | bool | None = None) -> Resources:
         ''' Provide a :class:`~bokeh.resources.Resources` that specifies where
         Bokeh application sessions should load BokehJS resources from.
 
         Args:
-            absolute_url (bool):
-                An absolute URL prefix to use for locating resources. If None,
-                relative URLs are used (default: None)
+            absolute_url (str, bool):
+                An absolute URL prefix to use for locating resources. If
+                ``True``, a prefix consisting of server's protocol, host
+                and port will be used. Otherwise, root-relative URLs are
+                used (default: ``None``)
 
         '''
         mode = settings.resources(default="server")
         if mode == "server" or mode == "server-dev":
-            root_url = urljoin(absolute_url or self._absolute_url or "", self._prefix)
-            return Resources(mode="server", root_url=root_url, path_versioner=StaticHandler.append_version)
+            if absolute_url is True:
+                absolute_url = self._absolute_url
+            if absolute_url is None or absolute_url is False:
+                absolute_url = "/"
+
+            root_url = urljoin(absolute_url, self._prefix)
+            return Resources(mode=mode, root_url=root_url, path_versioner=StaticHandler.append_version)
+
         return Resources(mode=mode)
 
     def start(self) -> None:
