@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -35,13 +35,13 @@ immediately supplied values
         settings.minified(minified_val)
 
     If ``minified_val`` is not None, then it will be returned, as-is.
-    Otherwise, if None is passed, then the setting will continute to look
+    Otherwise, if None is passed, then the setting will continue to look
     down the search order for a value. This is useful for passing optional
-    function paramters that are None by default. If the parameter is passed
+    function parameters that are None by default. If the parameter is passed
     to the function, then it will take precedence.
 
 previously user-set values
-    If the value is set explicity in code:
+    If the value is set explicitly in code:
 
     .. code-block:: python
 
@@ -84,7 +84,7 @@ local defaults
 
         settings.resources(default="server")
 
-    Local defaults have lower precendence than every other setting mechanism
+    Local defaults have lower precedence than every other setting mechanism
     except global defaults.
 
 global defaults
@@ -164,6 +164,11 @@ def convert_str(value: str) -> str:
     '''
     return value
 
+def convert_int(value: int | str) -> int:
+    ''' Convert a string to an integer.
+    '''
+    return int(value)
+
 def convert_bool(value: bool | str) -> bool:
     ''' Convert a string to True or False.
 
@@ -492,6 +497,8 @@ class PrioritizedSetting(Generic[T]):
             return "String"
         if self._convert is convert_bool:
             return "Bool"
+        if self._convert is convert_int:
+            return "Int"
         if self._convert is convert_logging:
             return "Log Level"
         if self._convert is convert_str_seq:
@@ -567,6 +574,15 @@ class Settings:
     See the :class:`~bokeh.resources.Resources` class reference for full details.
     """)
 
+    chromedriver_path: PrioritizedSetting[str | None] = PrioritizedSetting("chromedriver_path", "BOKEH_CHROMEDRIVER_PATH", default=None, help="""
+    The name of or full path to chromedriver's executable.
+
+    This is used to allow ``bokeh.io.export`` to work on systems that use a
+    different name for ``chromedriver``, like ``chromedriver-binary`` or
+    ``chromium.chromedriver`` (or its variant, which is used for example
+    by Snap package manager; see https://snapcraft.io/).
+    """)
+
     cookie_secret: PrioritizedSetting[str | None] = PrioritizedSetting("cookie_secret", "BOKEH_COOKIE_SECRET", default=None, help="""
     Configure the ``cookie_secret`` setting in Tornado. This value is required
     if you use ``get_secure_cookie`` or ``set_secure_cookie``.  It should be a
@@ -685,6 +701,14 @@ class Settings:
     See the :class:`~bokeh.resources.Resources` class reference for full details.
     """)
 
+    default_server_host: PrioritizedSetting[str] = PrioritizedSetting("default_server_host", "BOKEH_DEFAULT_SERVER_HOST", default="localhost", help="""
+    Allows to define the default host used by Bokeh's server and resources.
+    """)
+
+    default_server_port: PrioritizedSetting[int] = PrioritizedSetting("default_server_port", "BOKEH_DEFAULT_SERVER_PORT", default=5006, convert=convert_int, help="""
+    Allows to define the default port used by Bokeh's server and resources.
+    """)
+
     secret_key: PrioritizedSetting[str | None] = PrioritizedSetting("secret_key", "BOKEH_SECRET_KEY", default=None, help="""
     A long, cryptographically-random secret unique to a Bokeh deployment.
     """)
