@@ -1,5 +1,5 @@
 # -----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -14,7 +14,8 @@ The ``bokeh-example-metadata`` directive can be used by supplying:
         :refs: `ug_basic_bars`
         :words: bar, vbar, legend, factor_cmap, palette
 
-
+To enable this extension, add `"bokeh.sphinxext.bokeh_example_metadata"` to the
+extensions list in your Sphinx configuration module.
 
 """
 
