@@ -1,5 +1,5 @@
 # -----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -72,6 +72,9 @@ The inline example code above produces the following output:
 
     show(p)
 
+To enable this extension, add `"bokeh.sphinxext.bokeh_plot"` to the extensions
+list in your Sphinx configuration module.
+
 """
 
 #-----------------------------------------------------------------------------
