@@ -1,5 +1,5 @@
 # -----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -10,7 +10,11 @@ The ``bokeh-sampledata-xref`` directive can be used by supplying:
 
     .. bokeh-sampledata-xref:: sampledata_iris
 
-This can be used to add links to all existing standalone examples in the documentation.
+This can be used to add links to all existing standalone examples in the
+documentation.
+
+To enable this extension, add `"bokeh.sphinxext.bokeh_sampledata_xref"` to the
+extensions list in your Sphinx configuration module.
 
 """
 
