@@ -1,5 +1,5 @@
 # -----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -14,6 +14,9 @@ All that is required to generate the sitemap is to list this module
 ``bokeh.sphinxext.sitemap`` in the list of extensions in the Sphinx
 configuration file ``conf.py``.
 
+To enable this extension, add `"bokeh.sphinxext.bokeh_sitemap"` to the
+extensions list in your Sphinx configuration module.
+
 """
 
 # -----------------------------------------------------------------------------
