@@ -1,5 +1,5 @@
 # -----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -39,11 +39,16 @@ The inline example code above produces the following output:
 
     alert('this is called in the codepen');
 
+To enable this extension, add `"bokeh.sphinxext.bokehjs_content"` to the
+extensions list in your Sphinx configuration module.
+
 """
 
 # -----------------------------------------------------------------------------
 # Boilerplate
 # -----------------------------------------------------------------------------
+from __future__ import annotations
+
 import logging  # isort:skip
 
 log = logging.getLogger(__name__)
@@ -65,16 +70,15 @@ from sphinx.util import logging, parselinenos
 from sphinx.util.nodes import set_source_info
 
 # Bokeh imports
-from .templates import BJS_CODEPEN_INIT, BJS_EPILOGUE, BJS_HTML, BJS_PROLOGUE
+from . import PARALLEL_SAFE
+from .templates import (
+    BJS_CODEPEN_INIT,
+    BJS_EPILOGUE,
+    BJS_HTML,
+    BJS_PROLOGUE,
+)
 from .util import get_sphinx_resources
 
-if False:
-    # For type annotation
-    # from directives.code.CodeBlock.run
-    from typing import Any, Dict, List, Tuple  # NOQA
-    from sphinx.application import Sphinx  # NOQA
-    from sphinx.config import Config  # NOQA
-
 # -----------------------------------------------------------------------------
 # Globals and constants
 # -----------------------------------------------------------------------------
@@ -82,8 +86,6 @@ if False:
 __all__ = (
     "bokehjs_content",
     "BokehJSContent",
-    "html_depart_bokehjs_content",
-    "html_visit_bokehjs_content",
     "setup",
 )
 
@@ -97,7 +99,21 @@ __all__ = (
 
 
 class bokehjs_content(nodes.General, nodes.Element):
-    pass
+
+    @staticmethod
+    def visit_html(visitor, node):
+        if node["include_bjs_header"]:
+            # we only want to inject the CODEPEN_INIT on one bokehjs-content block per page
+            resources = get_sphinx_resources(include_bokehjs_api=True)
+            visitor.body.append(BJS_CODEPEN_INIT.render(css_files=resources.css_files, js_files=resources.js_files))
+
+        visitor.body.append(BJS_PROLOGUE.render(id=node["target_id"], title=node["title"]))
+
+    @staticmethod
+    def depart_html(visitor, node):
+        visitor.body.append(BJS_EPILOGUE.render(title=node["title"], enable_codepen=not node["disable_codepen"], js_source=node["js_source"]))
+
+    html = visit_html.__func__, depart_html.__func__
 
 
 class BokehJSContent(CodeBlock):
@@ -169,20 +185,19 @@ class BokehJSContent(CodeBlock):
         return [literal]
 
     def get_js_source(self):
-        env = self.state.document.settings.env
         js_file = self.options.get("js_file", False)
         # js_file *or* js code content, but not both
         if js_file and self.content:
             raise SphinxError("bokehjs-content:: directive can't have both js_file and content")
 
         if js_file:
-            log.debug(f"[bokehjs-content] handling external example in {env.docname!r}: {js_file}")
+            log.debug(f"[bokehjs-content] handling external example in {self.env.docname!r}: {js_file}")
             path = js_file
             if not js_file.startswith("/"):
-                path = join(env.app.srcdir, path)
+                path = join(self.env.app.srcdir, path)
             js_source = open(path).read()
         else:
-            log.debug(f"[bokehjs-content] handling inline example in {env.docname!r}")
+            log.debug(f"[bokehjs-content] handling inline example in {self.env.docname!r}")
             js_source = "\n".join(self.content)
 
         return js_source
@@ -200,12 +215,10 @@ class BokehJSContent(CodeBlock):
             return [js_source, "javascript"]
 
     def run(self):
-        env = self.state.document.settings.env
-
         rst_source = self.state_machine.node.document["source"]
         rst_filename = basename(rst_source)
 
-        serial_no = env.new_serialno("ccb")
+        serial_no = self.env.new_serialno("ccb")
         target_id = f"{rst_filename}.ccb-{serial_no}"
         target_id = target_id.replace(".", "-")
         target_node = nodes.target("", "", ids=[target_id])
@@ -234,30 +247,12 @@ class BokehJSContent(CodeBlock):
         return [target_node, node]
 
 
-def html_visit_bokehjs_content(self, node):
-    if node["include_bjs_header"]:
-        # we only want to inject the CODEPEN_INIT on one
-        # bokehjs-content block per page
-        resources = get_sphinx_resources(include_bokehjs_api=True)
-        self.body.append(BJS_CODEPEN_INIT.render(css_files=resources.css_files, js_files=resources.js_files))
-
-    self.body.append(
-        BJS_PROLOGUE.render(
-            id=node["target_id"],
-            title=node["title"],
-        )
-    )
-
-
-def html_depart_bokehjs_content(self, node):
-    self.body.append(BJS_EPILOGUE.render(title=node["title"], enable_codepen=not node["disable_codepen"], js_source=node["js_source"]))
-
-
 def setup(app):
     """ Required Sphinx extension setup function. """
-    app.add_node(bokehjs_content, html=(html_visit_bokehjs_content, html_depart_bokehjs_content))
+    app.add_node(bokehjs_content, html=bokehjs_content.html)
     app.add_directive("bokehjs-content", BokehJSContent)
 
+    return PARALLEL_SAFE
 
 # -----------------------------------------------------------------------------
 # Private API
